@@ -963,9 +963,7 @@ void KDirModelTest::testFilter()
     QVERIFY(m_dirIndex.isValid());
     const int oldTopLevelRowCount = m_dirModel->rowCount();
     const int oldSubdirRowCount = m_dirModel->rowCount(m_dirIndex);
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 100)
     QSignalSpy spyItemsFilteredByMime(m_dirModel->dirLister(), &KCoreDirLister::itemsFilteredByMime);
-#endif
     QSignalSpy spyItemsDeleted(m_dirModel->dirLister(), &KCoreDirLister::itemsDeleted);
     QSignalSpy spyRowsRemoved(m_dirModel, &QAbstractItemModel::rowsRemoved);
     m_dirModel->dirLister()->setNameFilter(QStringLiteral("toplevel*"));
@@ -1002,13 +1000,9 @@ void KDirModelTest::testFilter()
     QCOMPARE(spyItemsDeleted[0][0].value<KFileItemList>().count(), 1); // one from toplevel ('special chars')
     QCOMPARE(spyItemsDeleted[1][0].value<KFileItemList>().count(), 2); // two from subdir
     QCOMPARE(spyItemsDeleted[2][0].value<KFileItemList>().count(), 1); // one from subsubdir
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 100)
     QCOMPARE(spyItemsFilteredByMime.count(), 0);
-#endif
     spyItemsDeleted.clear();
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 100)
     spyItemsFilteredByMime.clear();
-#endif
 
     // Reset the filter
     qDebug() << "reset to no filter";
@@ -1018,9 +1012,7 @@ void KDirModelTest::testFilter()
     QCOMPARE(m_dirModel->rowCount(), oldTopLevelRowCount);
     QCOMPARE(m_dirModel->rowCount(m_dirIndex), oldSubdirRowCount);
     QCOMPARE(spyItemsDeleted.count(), 0);
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 100)
     QCOMPARE(spyItemsFilteredByMime.count(), 0);
-#endif
 
     // The order of things changed because of filtering.
     // Fill again, so that m_fileIndex etc. are correct again.
@@ -1075,12 +1067,10 @@ void KDirModelTest::testMimeFilter()
     QVERIFY(m_dirIndex.isValid());
     const int oldTopLevelRowCount = m_dirModel->rowCount();
     const int oldSubdirRowCount = m_dirModel->rowCount(m_dirIndex);
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 100)
     QSignalSpy spyItemsFilteredByMime(m_dirModel->dirLister(), &KCoreDirLister::itemsFilteredByMime);
-#endif
     QSignalSpy spyItemsDeleted(m_dirModel->dirLister(), &KCoreDirLister::itemsDeleted);
     QSignalSpy spyRowsRemoved(m_dirModel, &QAbstractItemModel::rowsRemoved);
-    m_dirModel->dirLister()->setMimeFilter(QStringList{QStringLiteral("application/pdf")});
+    m_dirModel->dirLister()->setMimeFilter({QStringLiteral("application/pdf")});
     QCOMPARE(m_dirModel->rowCount(), oldTopLevelRowCount); // no change yet
     QCOMPARE(m_dirModel->rowCount(m_dirIndex), oldSubdirRowCount); // no change yet
     m_dirModel->dirLister()->emitChanges();
@@ -1089,27 +1079,52 @@ void KDirModelTest::testMimeFilter()
 
     QVERIFY(spyRowsRemoved.count() >= 1); // depends on contiguity...
     QVERIFY(spyItemsDeleted.count() >= 1); // once for every dir
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 100)
-    // Maybe it would make sense to have those items in itemsFilteredByMime,
-    // but well, for the only existing use of that signal (MIME type filter plugin),
-    // it's not really necessary, the plugin has seen those files before anyway.
-    // The signal is mostly useful for the case of listing a dir with a MIME type filter set.
-    // QCOMPARE(spyItemsFilteredByMime.count(), 1);
-    // QCOMPARE(spyItemsFilteredByMime[0][0].value<KFileItemList>().count(), 4);
-    spyItemsFilteredByMime.clear();
-#endif
+    QCOMPARE(spyItemsFilteredByMime.count(), 3);
     spyItemsDeleted.clear();
+    spyItemsFilteredByMime.clear();
 
     // Reset the filter
-    qDebug() << "reset to no filter";
-    m_dirModel->dirLister()->setMimeFilter(QStringList());
+    m_dirModel->dirLister()->setMimeFilter({});
+    m_dirModel->dirLister()->emitChanges();
+
+    QCOMPARE(m_dirModel->rowCount(), oldTopLevelRowCount);
+    QCOMPARE(spyItemsDeleted.count(), 0);
+    QCOMPARE(spyItemsFilteredByMime.count(), 0);
+
+    // The order of things changed because of filtering.
+    // Fill again, so that m_fileIndex etc. are correct again.
+    fillModel(true);
+}
+
+void KDirModelTest::testMimeExcludeFilter()
+{
+    QVERIFY(m_dirIndex.isValid());
+    const int oldTopLevelRowCount = m_dirModel->rowCount();
+    const int oldSubdirRowCount = m_dirModel->rowCount(m_dirIndex);
+    QSignalSpy spyItemsFilteredByMime(m_dirModel->dirLister(), &KCoreDirLister::itemsFilteredByMime);
+    QSignalSpy spyItemsDeleted(m_dirModel->dirLister(), &KCoreDirLister::itemsDeleted);
+    QSignalSpy spyRowsRemoved(m_dirModel, &QAbstractItemModel::rowsRemoved);
+    m_dirModel->dirLister()->setMimeExcludeFilter({QStringLiteral("application/pdf")});
+    QCOMPARE(m_dirModel->rowCount(), oldTopLevelRowCount); // no change yet
+    QCOMPARE(m_dirModel->rowCount(m_dirIndex), oldSubdirRowCount); // no change yet
+    m_dirModel->dirLister()->emitChanges();
+
+    QCOMPARE(m_dirModel->rowCount(), oldTopLevelRowCount - 1); // no pdf files anymore
+
+    QCOMPARE(spyRowsRemoved.count(), 1); // one pdf file removed ...
+    QCOMPARE(spyItemsDeleted.count(), 1);
+    QCOMPARE(spyItemsFilteredByMime.count(), 1);
+    QCOMPARE(spyItemsFilteredByMime[0][0].value<KFileItemList>().count(), 1);
+    spyItemsFilteredByMime.clear();
+    spyItemsDeleted.clear();
+
+    // Reset the exclude filter
+    m_dirModel->dirLister()->setMimeExcludeFilter({});
     m_dirModel->dirLister()->emitChanges();
 
     QCOMPARE(m_dirModel->rowCount(), oldTopLevelRowCount);
     QCOMPARE(spyItemsDeleted.count(), 0);
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 100)
     QCOMPARE(spyItemsFilteredByMime.count(), 0);
-#endif
 
     // The order of things changed because of filtering.
     // Fill again, so that m_fileIndex etc. are correct again.
@@ -1700,8 +1715,6 @@ void KDirModelTest::testDeleteCurrentDirectory()
 
     QSignalSpy spyRowsRemoved(m_dirModel, &QAbstractItemModel::rowsRemoved);
 
-    KDirWatch::self()->statistics();
-
     KIO::DeleteJob *job = KIO::del(url, KIO::HideProgressInfo);
     QVERIFY(job->exec());
 
@@ -1738,7 +1751,7 @@ void KDirModelTest::testQUrlHash()
 {
     const int count = 3000;
     // Prepare an array of QUrls so that url constructing isn't part of the timing
-    QVector<QUrl> urls;
+    QList<QUrl> urls;
     urls.resize(count);
     for (int i = 0; i < count; ++i) {
         urls[i] = QUrl("http://www.kde.org/path/" + QString::number(i));
