@@ -11,6 +11,7 @@
 #include <KUriFilter>
 #include <QLoggingCategory>
 
+#include <KPluginMetaData>
 #include <QDir>
 #include <QHostInfo>
 #include <QRegularExpression>
@@ -168,7 +169,6 @@ void KUriFilterTest::initTestCase()
     datahome = qgetenv("DATAHOME");
     qDebug() << "libpaths" << QCoreApplication::libraryPaths();
 
-    qputenv("KDE_FORK_SLAVES", "yes"); // simpler, for the final cleanup
     QLoggingCategory::setFilterRules(QStringLiteral("kf.kio.urifilters.*=true"));
 
     QString searchProvidersDir = QFINDTESTDATA("../src/urifilters/ikws/searchproviders/google.desktop").section('/', 0, -2);
@@ -179,36 +179,27 @@ void KUriFilterTest::initTestCase()
     // There is no default search engine by default (since it was annoying when making typos),
     // so the user has to set it up, which we do here.
     {
-        KConfigGroup cfg(KSharedConfig::openConfig(QStringLiteral("kuriikwsfilterrc"), KConfig::SimpleConfig), "General");
+        KConfigGroup cfg(KSharedConfig::openConfig(QStringLiteral("kuriikwsfilterrc"), KConfig::SimpleConfig), QStringLiteral("General"));
         cfg.writeEntry("DefaultWebShortcut", "google");
         cfg.writeEntry("KeywordDelimiter", QString(s_delimiter));
         cfg.sync();
     }
 
-    // Copy kshorturifilterrc from the src dir so we don't depend on make install / env vars.
-    {
-        const QString rcFile = QFINDTESTDATA("../src/urifilters/shorturi/kshorturifilterrc");
-        QVERIFY(!rcFile.isEmpty());
-        const QString localFile = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + "/kshorturifilterrc";
-        QFile::remove(localFile);
-        QVERIFY(QFile(rcFile).copy(localFile));
-    }
-
     QDir().mkpath(datahome + QStringLiteral("/urifilter"));
 }
 
 void KUriFilterTest::pluginNames()
 {
     const QStringList plugins = KUriFilter::self()->pluginNames();
-    qDebug() << plugins;
-    const QByteArray debugString = plugins.join(',').toLatin1();
+    const QByteArray debugData = plugins.join(',').toLatin1();
+    const char *debugString = debugData.constData();
     // To make it possible to have external plugins (if there's any...)
     // we don't just have an expected result list, we just probe it for specific entries.
-    QVERIFY2(plugins.contains("kshorturifilter"), debugString.constData());
-    QVERIFY2(plugins.contains("kurisearchfilter"), debugString.constData());
-    QVERIFY2(plugins.contains("localdomainurifilter"), debugString.constData());
-    QVERIFY2(plugins.contains("fixhosturifilter"), debugString.constData());
-    QVERIFY2(plugins.contains("kuriikwsfilter"), debugString.constData());
+    QVERIFY2(plugins.contains("kshorturifilter"), debugString);
+    QVERIFY2(plugins.contains("kurisearchfilter"), debugString);
+    QVERIFY2(plugins.contains("localdomainurifilter"), debugString);
+    QVERIFY2(plugins.contains("fixhosturifilter"), debugString);
+    QVERIFY2(plugins.contains("kuriikwsfilter"), debugString);
     // No duplicates
     QCOMPARE(plugins.count("kshorturifilter"), 1);
 }
@@ -379,12 +370,12 @@ void KUriFilterTest::executables_data()
     setupColumns();
     // Executable tests - No IKWS in minicli
     addRow("cp", QStringLiteral("cp"), KUriFilterData::Executable, minicliFilters);
-    addRow("kbuildsycoca5", QStringLiteral("kbuildsycoca5"), KUriFilterData::Executable, minicliFilters);
+    addRow("kbuildsycoca6", QStringLiteral("kbuildsycoca6"), KUriFilterData::Executable, minicliFilters);
     addRow("KDE", QStringLiteral("KDE"), s_noFiltering, minicliFilters);
     addRow("does/not/exist", QStringLiteral("does/not/exist"), s_noFiltering, minicliFilters);
     addRow("/does/not/exist", QStringLiteral("/does/not/exist"), KUriFilterData::LocalFile, minicliFilters);
     addRow("/does/not/exist#a", QStringLiteral("/does/not/exist#a"), KUriFilterData::LocalFile, minicliFilters);
-    addRow("kbuildsycoca5 --help", QStringLiteral("kbuildsycoca5 --help"), KUriFilterData::Executable, minicliFilters); // the args are in argsAndOptions()
+    addRow("kbuildsycoca6 --help", QStringLiteral("kbuildsycoca6 --help"), KUriFilterData::Executable, minicliFilters); // the args are in argsAndOptions()
     addRow("/bin/sh", QStringLiteral("/bin/sh"), KUriFilterData::Executable, minicliFilters);
     addRow("/bin/sh -q -option arg1",
            QStringLiteral("/bin/sh -q -option arg1"),
@@ -518,3 +509,5 @@ void KUriFilterTest::relativeGoUp()
     // Then the text isn't filtered and returned as-is
     QVERIFY(!KUriFilter::self()->filterUri(filteredData, filtersList));
 }
+
+#include "moc_kurifiltertest.cpp"
