@@ -234,7 +234,7 @@ void KFileItemPrivate::init() const
                 m_bLink = true;
                 if (QT_STAT(pathBA.constData(), &buf) == 0) {
                     mode = buf.st_mode;
-                } else { // link pointing to nowhere (see FileProtocol::createUDSEntry() in ioslaves/file/file.cpp)
+                } else { // link pointing to nowhere (see FileProtocol::createUDSEntry() in kioworkers/file/file.cpp)
                     mode = (QT_STAT_MASK - 1) | S_IRWXU | S_IRWXG | S_IRWXO;
                 }
             }
@@ -247,8 +247,10 @@ void KFileItemPrivate::init() const
             m_entry.replace(KIO::UDSEntry::UDS_MODIFICATION_TIME, buf.st_mtime); // TODO: we could use msecs too...
             m_entry.replace(KIO::UDSEntry::UDS_ACCESS_TIME, buf.st_atime);
 #ifndef Q_OS_WIN
-            m_entry.replace(KIO::UDSEntry::UDS_USER, KUser(buf.st_uid).loginName());
-            m_entry.replace(KIO::UDSEntry::UDS_GROUP, KUserGroup(buf.st_gid).name());
+            const auto uid = buf.st_uid;
+            const auto gid = buf.st_gid;
+            m_entry.replace(KIO::UDSEntry::UDS_LOCAL_USER_ID, uid);
+            m_entry.replace(KIO::UDSEntry::UDS_LOCAL_GROUP_ID, gid);
 #endif
 
             // TODO: these can be removed, we can use UDS_FILE_TYPE and UDS_ACCESS everywhere
@@ -264,6 +266,12 @@ void KFileItemPrivate::init() const
                 appendACLAtoms(pathBA, m_entry, type);
             }
 #endif
+        } else {
+            if (errno != ENOENT) {
+                // another error
+                qCDebug(KIO_CORE) << QStringLiteral("KFileItem: error %1: %2").arg(errno).arg(QString::fromLatin1(strerror(errno))) << "when refreshing"
+                                  << m_url;
+            }
         }
     }
 
@@ -572,13 +580,6 @@ KFileItem::KFileItem(const KIO::UDSEntry &entry, const QUrl &itemOrDirUrl, bool
 {
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 0)
-KFileItem::KFileItem(mode_t mode, mode_t permissions, const QUrl &url, bool delayedMimeTypes)
-    : d(new KFileItemPrivate(KIO::UDSEntry(), mode, permissions, url, false, delayedMimeTypes, KFileItem::NormalMimeTypeDetermination))
-{
-}
-#endif
-
 KFileItem::KFileItem(const QUrl &url, const QString &mimeType, mode_t mode)
     : d(new KFileItemPrivate(KIO::UDSEntry(), mode, KFileItem::Unknown, url, false, false, KFileItem::NormalMimeTypeDetermination))
 {
@@ -807,8 +808,26 @@ QString KFileItem::user() const
     if (!d) {
         return QString();
     }
+    if (entry().contains(KIO::UDSEntry::UDS_USER)) {
+        return entry().stringValue(KIO::UDSEntry::UDS_USER);
+    } else {
+#ifdef Q_OS_UNIX
+        auto uid = entry().numberValue(KIO::UDSEntry::UDS_LOCAL_USER_ID, -1);
+        if (uid != -1) {
+            return KUser(uid).loginName();
+        }
+#endif
+    }
+    return QString();
+}
 
-    return entry().stringValue(KIO::UDSEntry::UDS_USER);
+int KFileItem::userId() const
+{
+    if (!d) {
+        return -1;
+    }
+
+    return entry().numberValue(KIO::UDSEntry::UDS_LOCAL_USER_ID, -1);
 }
 
 QString KFileItem::group() const
@@ -817,7 +836,26 @@ QString KFileItem::group() const
         return QString();
     }
 
-    return entry().stringValue(KIO::UDSEntry::UDS_GROUP);
+    if (entry().contains(KIO::UDSEntry::UDS_GROUP)) {
+        return entry().stringValue(KIO::UDSEntry::UDS_GROUP);
+    } else {
+#ifdef Q_OS_UNIX
+        auto gid = entry().numberValue(KIO::UDSEntry::UDS_LOCAL_GROUP_ID, -1);
+        if (gid != -1) {
+            return KUserGroup(gid).name();
+        }
+#endif
+    }
+    return QString();
+}
+
+int KFileItem::groupId() const
+{
+    if (!d) {
+        return -1;
+    }
+
+    return entry().numberValue(KIO::UDSEntry::UDS_LOCAL_GROUP_ID, -1);
 }
 
 bool KFileItemPrivate::isSlow() const
@@ -1015,7 +1053,7 @@ static QString iconFromDesktopFile(const QString &path)
                 // We need to find if the trash is empty, preferably without using a KIO job.
                 // So instead kio_trash leaves an entry in its config file for us.
                 KConfig trashConfig(QStringLiteral("trashrc"), KConfig::SimpleConfig);
-                if (trashConfig.group("Status").readEntry("Empty", true)) {
+                if (trashConfig.group(QStringLiteral("Status")).readEntry("Empty", true)) {
                     return emptyIcon;
                 }
             }
@@ -1139,21 +1177,6 @@ QStringList KFileItem::overlays() const
         if (group.hasKey("Exec") && !KDesktopFile::isAuthorizedDesktopFile(localPath())) {
             names.append(QStringLiteral("emblem-important"));
         }
-
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 82)
-        if (cfg.hasDeviceType()) {
-            QT_WARNING_PUSH
-            QT_WARNING_DISABLE_DEPRECATED
-            const QString dev = cfg.readDevice();
-            QT_WARNING_POP
-            if (!dev.isEmpty()) {
-                KMountPoint::Ptr mountPoint = KMountPoint::currentMountPoints().findByDevice(dev);
-                if (mountPoint) { // mounted?
-                    names.append(QStringLiteral("emblem-mounted"));
-                }
-            }
-        }
-#endif
     }
 
     if (isHidden()) {
@@ -1191,14 +1214,6 @@ bool KFileItem::isReadable() const
 
     d->ensureInitialized();
 
-    /*
-      struct passwd * user = getpwuid( geteuid() );
-      bool isMyFile = (QString::fromLocal8Bit(user->pw_name) == d->m_user);
-      // This gets ugly for the group....
-      // Maybe we want a static QString for the user and a static QStringList
-      // for the groups... then we need to handle the deletion properly...
-      */
-
     if (d->m_permissions != KFileItem::Unknown) {
         const mode_t readMask = S_IRUSR | S_IRGRP | S_IROTH;
         // No read permission at all
@@ -1210,6 +1225,27 @@ bool KFileItem::isReadable() const
         if ((d->m_permissions & readMask) == readMask) {
             return true;
         }
+
+#ifndef Q_OS_WIN
+        const auto uid = userId();
+        if (uid != -1) {
+            if (((uint) uid) == KUserId::currentUserId().nativeId()) {
+                return S_IRUSR & d->m_permissions;
+            }
+            const auto gid = groupId();
+            if (gid != -1) {
+                const KUser kuser = KUser(uid);
+                if (kuser.groups().contains(KUserGroup(gid))) {
+                    return S_IRGRP & d->m_permissions;
+                }
+
+                return S_IROTH & d->m_permissions;
+            }
+        }
+#else
+        // simple special case
+        return S_IRUSR & d->m_permissions;
+#endif
     }
 
     // Or if we can't read it - not network transparent
@@ -1228,19 +1264,32 @@ bool KFileItem::isWritable() const
 
     d->ensureInitialized();
 
-    /*
-      struct passwd * user = getpwuid( geteuid() );
-      bool isMyFile = (QString::fromLocal8Bit(user->pw_name) == d->m_user);
-      // This gets ugly for the group....
-      // Maybe we want a static QString for the user and a static QStringList
-      // for the groups... then we need to handle the deletion properly...
-      */
-
     if (d->m_permissions != KFileItem::Unknown) {
         // No write permission at all
-        if (!(S_IWUSR & d->m_permissions) && !(S_IWGRP & d->m_permissions) && !(S_IWOTH & d->m_permissions)) {
+        if ((d->m_permissions & (S_IWUSR | S_IWGRP | S_IWOTH)) == 0) {
             return false;
         }
+
+#ifndef Q_OS_WIN
+        const auto uid = userId();
+        if (uid != -1) {
+            if (((uint) uid) == KUserId::currentUserId().nativeId()) {
+                return S_IWUSR & d->m_permissions;
+            }
+            const auto gid = groupId();
+            if (gid != -1) {
+                const KUser kuser = KUser(uid);
+                if (kuser.groups().contains(KUserGroup(gid))) {
+                    return S_IWGRP & d->m_permissions;
+                }
+
+                return S_IWOTH & d->m_permissions;
+            }
+        }
+#else
+        // simple special case
+        return S_IWUSR & d->m_permissions;
+#endif
     }
 
     // Or if we can't write it - not network transparent
@@ -1310,44 +1359,18 @@ bool KFileItem::isFile() const
     return !isDir();
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 0)
-bool KFileItem::acceptsDrops() const
-{
-    // A directory ?
-    if (isDir()) {
-        return isWritable();
-    }
-
-    // But only local .desktop files and executables
-    if (!d->m_bIsLocalUrl) {
-        return false;
-    }
-
-    if (mimetype() == QLatin1String("application/x-desktop")) {
-        return true;
-    }
-
-    // Executable, shell script ... ?
-    if (QFileInfo(d->m_url.toLocalFile()).isExecutable()) {
-        return true;
-    }
-
-    return false;
-}
-#endif
-
 QString KFileItem::getStatusBarInfo() const
 {
     if (!d) {
         return QString();
     }
 
-    auto toDisplayUrl = [this](const QUrl &url) {
+    auto toDisplayUrl = [](const QUrl &url) {
         QString dest;
         if (url.isLocalFile()) {
             dest = KShell::tildeCollapse(url.toLocalFile());
         } else {
-            dest = targetUrl().toDisplayString();
+            dest = url.toDisplayString();
         }
         return dest;
     };
@@ -1356,8 +1379,11 @@ QString KFileItem::getStatusBarInfo() const
     const QString comment = mimeComment();
 
     if (d->m_bLink) {
+        auto linkText = linkDest();
+        if (!linkText.startsWith(QStringLiteral("anon_inode:"))) {
+            linkText = toDisplayUrl(d->m_url.resolved(QUrl::fromUserInput(linkText)));
+        }
         text += QLatin1Char(' ');
-        QString linkText = toDisplayUrl(QUrl::fromUserInput(linkDest()));
         if (comment.isEmpty()) {
             text += i18n("(Symbolic Link to %1)", linkText);
         } else {
@@ -1453,32 +1479,6 @@ QString KFileItem::timeString(FileTimes which) const
     return QLocale::system().toString(d->time(which), QLocale::LongFormat);
 }
 
-#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 0)
-QString KFileItem::timeString(unsigned int which) const
-{
-    if (!d) {
-        return QString();
-    }
-
-    switch (which) {
-    case KIO::UDSEntry::UDS_ACCESS_TIME:
-        return timeString(AccessTime);
-    case KIO::UDSEntry::UDS_CREATION_TIME:
-        return timeString(CreationTime);
-    case KIO::UDSEntry::UDS_MODIFICATION_TIME:
-    default:
-        return timeString(ModificationTime);
-    }
-}
-#endif
-
-#if KIOCORE_BUILD_DEPRECATED_SINCE(4, 0)
-void KFileItem::assign(const KFileItem &item)
-{
-    *this = item;
-}
-#endif
-
 QUrl KFileItem::mostLocalUrl(bool *local) const
 {
     if (!d) {
@@ -1702,6 +1702,58 @@ bool KFileItem::isNull() const
     return d == nullptr;
 }
 
+bool KFileItem::exists() const
+{
+    if (!d) {
+        return false;
+    }
+    if (!d->m_bInitCalled) {
+        qCWarning(KIO_CORE) << "KFileItem: exists called when not initialised" << d->m_url;
+        return false;
+    }
+    return d->m_fileMode != KFileItem::Unknown;
+}
+
+bool KFileItem::isExecutable() const
+{
+    if (!d) {
+        return false;
+    }
+
+    d->ensureInitialized();
+
+    if (d->m_permissions == KFileItem::Unknown) {
+        return false;
+    }
+
+    const mode_t executableMask = S_IXGRP | S_IXUSR | S_IXOTH;
+    if ((d->m_permissions & executableMask) == 0) {
+        return false;
+    }
+
+#ifndef Q_OS_WIN
+    const auto uid = userId();
+    if (uid != -1) {
+        if (((uint)uid) == KUserId::currentUserId().nativeId()) {
+            return S_IXUSR & d->m_permissions;
+        }
+        const auto gid = groupId();
+        if (gid != -1) {
+            const KUser kuser = KUser(uid);
+            if (kuser.groups().contains(KUserGroup(gid))) {
+                return S_IXGRP & d->m_permissions;
+            }
+
+            return S_IXOTH & d->m_permissions;
+        }
+    }
+    return false;
+#else
+    // simple special case
+    return S_IXUSR & d->m_permissions;
+#endif
+}
+
 KFileItemList::KFileItemList()
 {
 }
@@ -1772,6 +1824,20 @@ bool KFileItem::isRegularFile() const
     return Utils::isRegFileMask(d->m_fileMode);
 }
 
+QString KFileItem::suffix() const
+{
+    if (!d || isDir()) {
+        return QString();
+    }
+
+    const int lastDot = d->m_strText.lastIndexOf(QStringLiteral("."));
+    if (lastDot > 0) {
+        return d->m_strText.mid(lastDot + 1);
+    } else {
+        return QString();
+    }
+}
+
 QDebug operator<<(QDebug stream, const KFileItem &item)
 {
     QDebugStateSaver saver(stream);
