@@ -59,31 +59,6 @@ public:
      */
     void sendAsyncData(const QByteArray &data);
 
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(4, 3)
-    /**
-     * When enabled, the job reports the amount of data that has been sent,
-     * instead of the amount of data that has been received.
-     * @see slotProcessedSize
-     * @see slotSpeed
-     * @deprecated since 4.2.1, this is unnecessary (it is always false for
-     *             KIO::get and true for KIO::put)
-     */
-    KIOCORE_DEPRECATED_VERSION(4, 3, "No longer needed")
-    void setReportDataSent(bool enabled);
-#endif
-
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(4, 3)
-    /**
-     *  Returns whether the job reports the amount of data that has been
-     *  sent (true), or whether the job reports the amount of data that
-     * has been received (false)
-     * @deprecated since 4.2.1, this is unnecessary (it is always false for
-     *             KIO::get and true for KIO::put)
-     */
-    KIOCORE_DEPRECATED_VERSION(4, 3, "No longer needed")
-    bool reportDataSent() const;
-#endif
-
     /**
      * Call this in the slot connected to result,
      * and only after making sure no error happened.
@@ -107,12 +82,6 @@ public:
     void setTotalSize(KIO::filesize_t bytes);
 
 protected:
-    /**
-     * Called when m_subJob finishes.
-     * @param job the job that finished
-     */
-    void slotResult(KJob *job) override;
-
     /**
      * Reimplemented for internal reasons
      */
@@ -161,17 +130,6 @@ Q_SIGNALS:
      */
     void permanentRedirection(KIO::Job *job, const QUrl &fromUrl, const QUrl &toUrl);
 
-#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 78)
-    /**
-     * MIME type determined.
-     * @param job the job that emitted this signal
-     * @param mimeType the MIME type
-     * @deprecated Since 5.78, use mimeTypeFound(KIO::Job *, const QString &)
-     */
-    KIOCORE_DEPRECATED_VERSION(5, 78, "Use KIO::TransferJob::mimeTypeFound(KIO::Job *, const QString &)")
-    void mimetype(KIO::Job *job, const QString &mimeType); // clazy:exclude=overloaded-signal
-#endif
-
     /**
      * MIME type determined.
      * @param job the job that emitted this signal
@@ -195,9 +153,6 @@ protected Q_SLOTS:
     virtual void slotData(const QByteArray &data);
     virtual void slotDataReq();
     virtual void slotMimetype(const QString &mimetype);
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 101) // override no longer needed
-    void slotMetaData(const KIO::MetaData &_metaData) override;
-#endif
 
 protected:
     KIOCORE_NO_EXPORT explicit TransferJob(TransferJobPrivate &dd);
@@ -222,7 +177,6 @@ private:
  *
  * @code
  *   job->putOnHold();
- *   KIO::Scheduler::publishSlaveOnHold();
  * @endcode
  *
  * and forget about the job. The next time someone does a KIO::get() on the
@@ -255,7 +209,6 @@ KIOCORE_EXPORT TransferJob *put(const QUrl &url, int permissions, JobFlags flags
  * \code
  *    job = KIO::http_post( url, postData, KIO::HideProgressInfo );
  *    job->addMetaData("content-type", contentType );
- *    job->addMetaData("referrer", referrerURL);
  * \endcode
  *
  * @p postData is the data that you want to send and
@@ -292,7 +245,6 @@ KIOCORE_EXPORT TransferJob *http_post(const QUrl &url, const QByteArray &postDat
  * @param flags Can be HideProgressInfo here
  * @return the job handling the operation.
  *
- * @since 4.7
  */
 KIOCORE_EXPORT TransferJob *http_post(const QUrl &url, QIODevice *device, qint64 size = -1, JobFlags flags = DefaultFlags);
 
