@@ -19,12 +19,11 @@ public:
     QString m_command;
     QString m_desktopName;
     QString m_executable;
-    QString m_iconName;
     QString m_workingDirectory;
     QStringList m_arguments;
     QByteArray m_startupId;
     QPointer<KProcessRunner> m_processRunner;
-    QProcessEnvironment m_environment;
+    QProcessEnvironment m_environment{QProcessEnvironment::InheritFromParent};
     qint64 m_pid = 0;
 };
 
@@ -67,13 +66,6 @@ void KIO::CommandLauncherJob::setExecutable(const QString &executable)
     d->m_executable = executable;
 }
 
-#if KIOGUI_BUILD_DEPRECATED_SINCE(5, 103)
-void KIO::CommandLauncherJob::setIcon(const QString &iconName)
-{
-    d->m_iconName = iconName;
-}
-#endif
-
 void KIO::CommandLauncherJob::setDesktopName(const QString &desktopName)
 {
     d->m_desktopName = desktopName;
@@ -116,25 +108,12 @@ void KIO::CommandLauncherJob::start()
     }
     Q_EMIT description(this, i18nc("Launching application", "Launching %1", displayName), {}, {});
 
-    if (d->m_iconName.isEmpty()) {
-        d->m_iconName = d->m_executable;
-    }
     if (d->m_command.isEmpty() && !d->m_executable.isEmpty()) {
-        d->m_processRunner = KProcessRunner::fromExecutable(d->m_executable,
-                                                            d->m_arguments,
-                                                            d->m_desktopName,
-                                                            d->m_iconName,
-                                                            d->m_startupId,
-                                                            d->m_workingDirectory,
-                                                            d->m_environment);
+        d->m_processRunner =
+            KProcessRunner::fromExecutable(d->m_executable, d->m_arguments, d->m_desktopName, d->m_startupId, d->m_workingDirectory, d->m_environment);
     } else {
-        d->m_processRunner = KProcessRunner::fromCommand(d->m_command,
-                                                         d->m_desktopName,
-                                                         d->m_executable,
-                                                         d->m_iconName,
-                                                         d->m_startupId,
-                                                         d->m_workingDirectory,
-                                                         d->m_environment);
+        d->m_processRunner =
+            KProcessRunner::fromCommand(d->m_command, d->m_desktopName, d->m_executable, d->m_startupId, d->m_workingDirectory, d->m_environment);
     }
     connect(d->m_processRunner, &KProcessRunner::error, this, [this](const QString &errorText) {
         setError(KJob::UserDefinedError);
